==> physiolabxr-0.1.0.dev7-py3-none-any.whl: physiolabxr/__init__.py <==


def physiolabxr():
    # try import pylsl check if the lib exist
    try:
        import pylsl
    except RuntimeError:
        # the error is LSL binary library file was not found.
        from physiolabxr.utils.setup_utils import get_lsl_binary
        get_lsl_binary()

    import multiprocessing
    import sys

    from PyQt6 import QtWidgets
    from PyQt6.QtGui import QIcon
    from PyQt6.QtWidgets import QSystemTrayIcon, QMenu

    from physiolabxr.configs.configs import AppConfigs
    from physiolabxr.ui.SplashScreen import SplashScreen

    AppConfigs(_reset=False)  # create the singleton app configs object
    from physiolabxr.ui.MainWindow import MainWindow
    from physiolabxr.startup.startup import load_settings

    app = None

    multiprocessing.freeze_support()  # for built exe

    # load the qt application
    app = QtWidgets.QApplication(sys.argv)
    app.setStyle("fusion")
    tray_icon = QSystemTrayIcon(QIcon(AppConfigs()._app_logo), parent=app)
    tray_icon.setToolTip('PhysioLabXR')
    tray_icon.show()

    # create the splash screen
    splash = SplashScreen()
    splash.show()

    # load default settings
    load_settings(revert_to_default=False, reload_presets=False)
    # main window init
    print("Creating main window")
    window = MainWindow(app=app)

    window.setWindowIcon(QIcon(AppConfigs()._app_logo))
    # make tray menu
    menu = QMenu()
    exit_action = menu.addAction('Exit')
    exit_action.triggered.connect(window.close)

    print("Closing splash screen, showing main window")
    # splash screen destroy
    splash.close()
    window.show()

    print("Entering exec loop")
    try:
        sys.exit(app.exec())
    except KeyboardInterrupt:
        print('App terminate by KeyboardInterrupt')
        sys.exit()

==> physiolabxr-1.0.0b2-py3-none-any.whl: physiolabxr/__init__.py <==


def physiolabxr():
    import multiprocessing
    import sys

    from PyQt6 import QtWidgets
    from PyQt6.QtGui import QIcon
    from PyQt6.QtWidgets import QSystemTrayIcon, QMenu

    from physiolabxr.configs.configs import AppConfigs
    from physiolabxr.ui.SplashScreen import SplashScreen

    AppConfigs(_reset=False)  # create the singleton app configs object

    app = None

    multiprocessing.freeze_support()  # for built exe

    # load the qt application
    app = QtWidgets.QApplication(sys.argv)
    app.setStyle("fusion")
    tray_icon = QSystemTrayIcon(QIcon(AppConfigs()._app_logo), parent=app)
    tray_icon.setToolTip('PhysioLabXR')
    tray_icon.show()

    # create the splash screen
    splash = SplashScreen()
    splash.show()

    # load default settings
    from physiolabxr.utils.setup_utils import run_setup_check
    run_setup_check()
    from physiolabxr.startup.startup import load_settings
    load_settings(revert_to_default=False, reload_presets=False)
    # main window init
    print("Creating main window")
    from physiolabxr.ui.MainWindow import MainWindow
    window = MainWindow(app=app)

    window.setWindowIcon(QIcon(AppConfigs()._app_logo))
    # make tray menu
    menu = QMenu()
    exit_action = menu.addAction('Exit')
    exit_action.triggered.connect(window.close)

    print("Closing splash screen, showing main window")
    # splash screen destroy
    splash.close()
    window.show()

    print("Entering exec loop")
    try:
        sys.exit(app.exec())
    except KeyboardInterrupt:
        print('App terminate by KeyboardInterrupt')
        sys.exit()
